==> google_applovin_unity_ads-1.1.3.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/CustomOpenAdDialog.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads

import android.app.Dialog
import android.content.Context
import android.content.Intent
import android.graphics.drawable.ColorDrawable
import android.graphics.drawable.Drawable
import android.net.Uri
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.WindowManager
import com.btcpiyush.ads.google_applovin_unity_ads.api.CustomAdsSetting
import com.btcpiyush.ads.google_applovin_unity_ads.circluar_timer.CircularTimerListener
import com.btcpiyush.ads.google_applovin_unity_ads.circluar_timer.TimeFormatEnum
import com.btcpiyush.ads.google_applovin_unity_ads.databinding.CustomOpenAdsBinding
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide.ImageLoad
import com.bumptech.glide.load.DataSource
import com.bumptech.glide.load.engine.GlideException
import com.bumptech.glide.request.target.Target
import java.util.*


data class CustomOpenAdDialog(
    val cntxt: Context,
    val setting: CustomAdsSetting,
    val appTitle: String? = null,
    val appLogo: String? = null,
    val listerner: DialogInterface,

) : Dialog(cntxt, android.R.style.Theme_Black_NoTitleBar_Fullscreen) {
    private var dialogbinding: CustomOpenAdsBinding? = null
    private var webUrl: String? = null
    private var appPackage: String? = null
    interface DialogInterface {
        fun onDismiss()
        fun onFailed()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        dialogbinding = CustomOpenAdsBinding.inflate(LayoutInflater.from(cntxt))
        dialogbinding?.let {
            setContentView(it.root)

            appTitle?.let{ title ->
                if(title.isNotEmpty()) {
                    it.appLabel.visibility = View.VISIBLE
                    it.appLabel.text = appTitle
                }
            }
            appLogo?.let{ logo ->
                if(logo.isNotEmpty()) {
                    it.appLogo.visibility = View.VISIBLE
                    ImageLoadGlide().imageLoad(
                        appLogo,
                        it.appLogo,
                        cntxt,
                        imageLoad = object: ImageLoad {
                            override fun onLoadFailed(
                                e: GlideException?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                isFirstResource: Boolean
                            ) {}

                            override fun onSuccess(
                                resource: Drawable?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                dataSource: DataSource?,
                                isFirstResource: Boolean
                            ) {}
                        }
                    )
                }
            }

            it.qurecaView.visibility = View.GONE
            it.applicationView.visibility = View.GONE

            setting.qurakaOpenAdImage?.let{ openADSetting ->

                if(openADSetting.openAdTimer > 0) {
                    it.nextImage.visibility = View.GONE
                    it.progressCircular.visibility = View.VISIBLE
                    it.progressCircular.setCircularTimerListener(object : CircularTimerListener {

                        override fun updateDataOnTick(remainingTimeInMs: Long): String {
                            return Math.ceil((remainingTimeInMs / 1000f).toDouble()).toInt().toString()
                        }

                        override fun onTimerFinished() {
                            it.nextImage.visibility = View.VISIBLE
                            it.progressCircular.visibility = View.GONE
                            it.progressCircular.text = openADSetting.openAdTimer.toString()
                            it.continueBtn.setOnClickListener {
                                dismiss()
                                listerner.onDismiss()
                                if (setting.closeButtonToDirectWeb == true) {
                                    webUrl?.let {
                                        openPage(it)
                                    }
                                }
                            }
                        }
                    }, openADSetting.openAdTimer.toLong(), TimeFormatEnum.SECONDS, 1000L)

                }


                if(openADSetting.isLiveApps == true) {

                    it.applicationView.visibility = View.VISIBLE

                    setting.qurakaOpenAdImage?.liveApps?.let { appRecords ->
                        if(appRecords.size >  0) {
                            var random_index = Random().nextInt(appRecords.size)

                            if (random_index >= appRecords.size) {
                                random_index = appRecords.size - 1
                            }
                            val record = appRecords[random_index]

                            record?.let{  record ->
                                record.fields?.let{ record ->
                                    record.playstoreLink?.let {
                                        webUrl = it
                                    }
                                    ImageLoadGlide().imageLoad(
                                        record.appImage,
                                        it.appAdLogoImage,
                                        cntxt,
                                        imageLoad = object: ImageLoad {
                                            override fun onLoadFailed(
                                                e: GlideException?,
                                                model: Any?,
                                                target: Target<Drawable?>?,
                                                isFirstResource: Boolean
                                            ) {
                                                dismiss()
                                                listerner.onFailed()
                                            }

                                            override fun onSuccess(
                                                resource: Drawable?,
                                                model: Any?,
                                                target: Target<Drawable?>?,
                                                dataSource: DataSource?,
                                                isFirstResource: Boolean
                                            ) {
                                                if(openADSetting.openAdTimer > 0) {
                                                    it.progressCircular.startTimer()
                                                } else {
                                                    it.nextImage.visibility = View.VISIBLE
                                                    it.progressCircular.visibility = View.GONE
                                                    it.continueBtn.setOnClickListener {
                                                        dismiss()
                                                        listerner.onDismiss()
                                                        if (setting.closeButtonToDirectWeb == true) {
                                                            webUrl?.let {
                                                                openPage(it)
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    )
                                    it.appAdLabel.text = record.appTitle
                                    record.playstoreLink?.split("id=")?.let { packga ->
                                        if(packga.size > 1) {
                                            appPackage = packga[1]
                                            if (appInstalledOrNot(appPackage!!)){
                                                it.appAdInstall.text =  "Open Now"
                                            }
                                        }
                                    }
                                }
                            }

                            it.appAdInstall.setOnClickListener {
                                appPackage?.let {
                                    try {
                                        val intent: Intent? = cntxt.packageManager.getLaunchIntentForPackage(it)
                                        cntxt.startActivity(intent)
                                    } catch (e: Exception) {
                                        webUrl?.let {
                                            openPage(it)
                                        }
                                    }
                                } ?: kotlin.run {
                                    webUrl?.let {
                                        openPage(it)
                                    }
                                }
                            }
                        }
                    }
                } else {
                    it.qurecaView.visibility = View.VISIBLE
                    var random_index = Random().nextInt(setting.qurakaIntraImage.size)

                    if (random_index >= setting.qurakaIntraImage.size) {
                        random_index = setting.qurakaIntraImage.size - 1
                    }

                    setting.qurekaLink?.let {
                        webUrl = it
                    }

                    ImageLoadGlide().imageLoad(
                        setting.qurakaIntraImage[random_index],
                        it.ivInterstitialImage,
                        cntxt,
                        imageLoad = object: ImageLoad {
                            override fun onLoadFailed(
                                e: GlideException?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                isFirstResource: Boolean
                            ) {
                                dismiss()
                                listerner.onFailed()
                            }

                            override fun onSuccess(
                                resource: Drawable?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                dataSource: DataSource?,
                                isFirstResource: Boolean
                            ) {
                                if(openADSetting.openAdTimer > 0) {
                                    it.progressCircular.startTimer()
                                } else {
                                    it.nextImage.visibility = View.VISIBLE
                                    it.progressCircular.visibility = View.GONE
                                    it.continueBtn.setOnClickListener {
                                        dismiss()
                                        listerner.onDismiss()
                                        if (setting.closeButtonToDirectWeb == true) {
                                            webUrl?.let {
                                                openPage(it)
                                            }
                                        }
                                    }
                                }
                            }
                        },
                        it.progressbar
                    )

                    it.ivInterstitialImage.setOnClickListener {
                        webUrl?.let {
                            openPage(it)
                        }
                    }

                }
            }

            //scroll_desc = (ScrollView) findViewById(R.id.scroll_desc);
            //Toast.makeText(this,new Random().nextInt(Custom_Ads_Model.ads_List.size()) +" : custom Ads : "+ Custom_Ads_Model.ads_List.size(),Toast.LENGTH_SHORT).show();
        }
        setCanceledOnTouchOutside(false)
        val layoutParams = WindowManager.LayoutParams()
        layoutParams.copyFrom(window?.attributes)
        layoutParams.width = WindowManager.LayoutParams.MATCH_PARENT
        layoutParams.height = WindowManager.LayoutParams.MATCH_PARENT
        window?.attributes = layoutParams
        window?.setBackgroundDrawable(ColorDrawable(android.graphics.Color.TRANSPARENT))
    }

    private fun appInstalledOrNot(uri: String): Boolean {
        try {
            val mainIntent = Intent(Intent.ACTION_MAIN, null)
            mainIntent.addCategory(Intent.CATEGORY_LAUNCHER)
            val pkgAppsList = cntxt.packageManager.queryIntentActivities(mainIntent, 0)
            for (resolveInfo in pkgAppsList) {
                Log.e(" ---------- ", resolveInfo.activityInfo.packageName)
                if (resolveInfo.activityInfo.packageName != null
                    && resolveInfo.activityInfo.packageName == uri
                ) {
                    return true
                }
            }
            return false
            return true
        } catch (e: Exception) {
        }
        return false
    }

    private fun openPage(url: String) {
        try {
            val browserIntent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
            browserIntent.setPackage("com.android.chrome")
            context.startActivity(browserIntent)
        } catch (e: Exception) {
            try {
                val browserIntent =
                    Intent(Intent.ACTION_VIEW, Uri.parse(url))
                context.startActivity(browserIntent)
            } catch (e: Exception) {
            }
        }
    }
}

==> google_applovin_unity_ads-1.1.7.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/CustomOpenAdDialog.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads

import android.app.Dialog
import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.graphics.drawable.ColorDrawable
import android.graphics.drawable.Drawable
import android.net.Uri
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.WindowManager
import com.btcpiyush.ads.google_applovin_unity_ads.api.CustomAdsSetting
import com.btcpiyush.ads.google_applovin_unity_ads.circluar_timer.CircularTimerListener
import com.btcpiyush.ads.google_applovin_unity_ads.circluar_timer.TimeFormatEnum
import com.btcpiyush.ads.google_applovin_unity_ads.databinding.CustomOpenAdsBinding
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide
import com.btcpiyush.ads.google_applovin_unity_ads.image_loader.ImageLoadGlide.ImageLoad
import com.bumptech.glide.load.DataSource
import com.bumptech.glide.load.engine.GlideException
import com.bumptech.glide.request.target.Target
import java.util.*


data class CustomOpenAdDialog(
    val cntxt: Context,
    val setting: CustomAdsSetting,
    val appTitle: String? = null,
    val appLogo: String? = null,
    val listerner: DialogInterface,

) : Dialog(cntxt, android.R.style.Theme_Black_NoTitleBar_Fullscreen) {
    private var dialogbinding: CustomOpenAdsBinding? = null
    private var webUrl: String? = null
    private var appPackage: String? = null
    interface DialogInterface {
        fun onLoaded()
        fun onDismiss()
        fun onFailed()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        dialogbinding = CustomOpenAdsBinding.inflate(LayoutInflater.from(cntxt))
        dialogbinding?.let {
            setContentView(it.root)

            appTitle?.let{ title ->
                if(title.isNotEmpty()) {
                    it.appLabel.visibility = View.VISIBLE
                    it.appLabel.text = appTitle
                }
            }
            appLogo?.let{ logo ->
                if(logo.isNotEmpty()) {
                    it.appLogo.visibility = View.VISIBLE
                    ImageLoadGlide().imageLoad(
                        appLogo,
                        it.appLogo,
                        cntxt,
                        imageLoad = object: ImageLoad {
                            override fun onLoadFailed(
                                e: GlideException?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                isFirstResource: Boolean
                            ) {}

                            override fun onSuccess(
                                resource: Drawable?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                dataSource: DataSource?,
                                isFirstResource: Boolean
                            ) {}
                        }
                    )
                }
            }

            it.qurecaView.visibility = View.GONE
            it.applicationView.visibility = View.GONE

            setting.qurakaOpenAdImage?.let{ openADSetting ->

                if(openADSetting.openAdTimer > 0) {
                    it.nextImage.visibility = View.GONE
                    it.progressCircular.visibility = View.VISIBLE
                    it.progressCircular.setCircularTimerListener(object : CircularTimerListener {

                        override fun updateDataOnTick(remainingTimeInMs: Long): String {
                            return Math.ceil((remainingTimeInMs / 1000f).toDouble()).toInt().toString()
                        }

                        override fun onTimerFinished() {
                            it.nextImage.visibility = View.VISIBLE
                            it.progressCircular.visibility = View.GONE
                            it.progressCircular.text = openADSetting.openAdTimer.toString()
                            it.continueBtn.setOnClickListener {
                                dismiss()
                                listerner.onDismiss()
                                /*if (setting.closeButtonToDirectWeb == true) {
                                    webUrl?.let {
                                        openPage(it)
                                    }
                                }*/
                            }
                        }
                    }, openADSetting.openAdTimer.toLong(), TimeFormatEnum.SECONDS, 1000L)

                }


                if(openADSetting.isLiveApps == true) {

                    it.applicationView.visibility = View.VISIBLE

                    setting.qurakaOpenAdImage?.liveApps?.let { appRecords ->
                        if(appRecords.size >  0) {
                            var random_index = Random().nextInt(appRecords.size)

                            if (random_index >= appRecords.size) {
                                random_index = appRecords.size - 1
                            }
                            val record = appRecords[random_index]

                            record?.let{  record ->
                                record.fields?.let{ record ->
                                    record.playstoreLink?.let {
                                        webUrl = it
                                    }
                                    ImageLoadGlide().imageLoad(
                                        record.appImage,
                                        it.appAdLogoImage,
                                        cntxt,
                                        imageLoad = object: ImageLoad {
                                            override fun onLoadFailed(
                                                e: GlideException?,
                                                model: Any?,
                                                target: Target<Drawable?>?,
                                                isFirstResource: Boolean
                                            ) {
                                                dismiss()
                                                listerner.onFailed()
                                            }

                                            override fun onSuccess(
                                                resource: Drawable?,
                                                model: Any?,
                                                target: Target<Drawable?>?,
                                                dataSource: DataSource?,
                                                isFirstResource: Boolean
                                            ) {
                                                listerner.onLoaded()
                                            }
                                        }
                                    )
                                    it.appAdLabel.text = record.appTitle
                                    record.playstoreLink?.split("id=")?.let { packga ->
                                        if(packga.size > 1) {
                                            appPackage = packga[1]
                                            if (appInstalledOrNot(appPackage!!)){
                                                it.appAdInstall.text =  "Open Now"
                                            } else {
                                                it.appAdInstall.text =  "Install Now"
                                            }
                                        }
                                    }
                                }
                            }

                            it.appAdInstall.setOnClickListener {
                                appPackage?.let {
                                    try {
                                        val intent: Intent? = cntxt.packageManager.getLaunchIntentForPackage(it)
                                        cntxt.startActivity(intent)
                                    } catch (e: Exception) {
                                        webUrl?.let {
                                            openPage(it)
                                        }
                                    }
                                } ?: kotlin.run {
                                    webUrl?.let {
                                        openPage(it)
                                    }
                                }
                            }
                        }
                    }
                } else {
                    it.qurecaView.visibility = View.VISIBLE
                    var random_index = Random().nextInt(setting.qurakaIntraImage.size)

                    if (random_index >= setting.qurakaIntraImage.size) {
                        random_index = setting.qurakaIntraImage.size - 1
                    }

                    setting.qurekaLink?.let {
                        webUrl = it
                    }

                    ImageLoadGlide().imageLoad(
                        setting.qurakaIntraImage[random_index],
                        it.ivInterstitialImage,
                        cntxt,
                        imageLoad = object: ImageLoad {
                            override fun onLoadFailed(
                                e: GlideException?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                isFirstResource: Boolean
                            ) {
                                dismiss()
                                listerner.onFailed()
                            }

                            override fun onSuccess(
                                resource: Drawable?,
                                model: Any?,
                                target: Target<Drawable?>?,
                                dataSource: DataSource?,
                                isFirstResource: Boolean
                            ) {
                                listerner.onLoaded()
                            }
                        },
                        it.progressbar
                    )

                    it.ivInterstitialImage.setOnClickListener {
                        webUrl?.let {
                            openPage(it)
                        }
                    }

                }
            }

            //scroll_desc = (ScrollView) findViewById(R.id.scroll_desc);
            //Toast.makeText(this,new Random().nextInt(Custom_Ads_Model.ads_List.size()) +" : custom Ads : "+ Custom_Ads_Model.ads_List.size(),Toast.LENGTH_SHORT).show();
        }
        setCanceledOnTouchOutside(false)
        val layoutParams = WindowManager.LayoutParams()
        layoutParams.copyFrom(window?.attributes)
        layoutParams.width = WindowManager.LayoutParams.MATCH_PARENT
        layoutParams.height = WindowManager.LayoutParams.MATCH_PARENT
        window?.attributes = layoutParams
        window?.setBackgroundDrawable(ColorDrawable(android.graphics.Color.TRANSPARENT))
    }

    fun setStartTimer() {
        Log.e("TAG", "setStartTimer: ")
        setting.qurakaOpenAdImage?.let{ openADSetting ->
            dialogbinding?.let {
                Log.e("TAG", "setStartTimer:  ${openADSetting.openAdTimer} ")
                if(openADSetting.openAdTimer > 0) {
                    it.progressCircular.startTimer()
                } else {
                    it.nextImage.visibility = View.VISIBLE
                    it.progressCircular.visibility = View.GONE
                    it.continueBtn.setOnClickListener {
                        dismiss()
                        listerner.onDismiss()
                        /*if (setting.closeButtonToDirectWeb == true) {
                            webUrl?.let {
                                openPage(it)
                            }
                        }*/
                    }
                }
            }
        }
    }

    private fun appInstalledOrNot(uri: String): Boolean {

        try {
            val mainIntent = Intent(Intent.ACTION_MAIN, null)
            mainIntent.addCategory(Intent.CATEGORY_LAUNCHER)
            val pkgAppsList = cntxt.packageManager.queryIntentActivities(mainIntent, 0)
            for (resolveInfo in pkgAppsList) {
                Log.e("${uri}", resolveInfo.activityInfo.packageName)
                if (resolveInfo.activityInfo.packageName != null
                    && resolveInfo.activityInfo.packageName == uri
                ) {
                    return true
                }
            }
            return false
        } catch (e: Exception) {
        }
        return false
    }

    private fun openPage(url: String) {
        try {
            val browserIntent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
            browserIntent.setPackage("com.android.chrome")
            context.startActivity(browserIntent)
        } catch (e: Exception) {
            try {
                val browserIntent =
                    Intent(Intent.ACTION_VIEW, Uri.parse(url))
                context.startActivity(browserIntent)
            } catch (e: Exception) {
            }
        }
    }
}
